@@ -1,4 +1,4 @@
-"""Template extractor"""
+"""Animania Extractor"""
 from __future__ import annotations
 
 from typing import AsyncGenerator, Dict, Generator, Protocol
@@ -230,6 +230,10 @@ class Video(BaseVideo):
     name: str
     dub: str
 
+    def __hash__(self):
+        # balancer netloc and dub_id
+        return hash((self._urlparse(self.url).netloc, self.dub))
+
 
 class TestCollections(BaseTestCollections):
     def test_search(self):
